@@ -24,6 +24,8 @@ from datetime import datetime
 from ..utils.general.Wrapit import Wrapit
 from hamcrest import assert_that, equal_to, none, not_none, contains_string
 
+from pytest_html import extras
+
 
 class Borg:
     # The borg design pattern is to share state
@@ -146,7 +148,8 @@ class Base_Page(Borg, unittest.TestCase):
             self.current_console_log_errors = []
             self.window_structure = {}
             self.testrail_flag = False
-            self.tesults_flag = True
+            self.tesults_flag = False
+            self.base64_flag = True
             self.images = []
             self.browserstack_flag = False
             self.highlight_flag = False
@@ -393,11 +396,14 @@ class Base_Page(Borg, unittest.TestCase):
         if self.browserstack_flag is True:
             self.append_latest_image(screenshot_name)
         if self.tesults_flag is True:
+            self.images.append(screenshot_name)
+        if self.base64_flag is True:
             with open(screenshot_name, "rb") as image_file:
                 encoded_string = base64.b64encode(image_file.read()).decode('utf-8')
                 self.images.append("data:image/png;base64," + encoded_string)
 
-        # Add screenshot to HTML report using Jinja2
+        # Add screenshot to HTML
+        # using Jinja2
         with open('report.html', 'w') as file:
             template = Template('''
                     <html>
@@ -1322,13 +1328,14 @@ class Base_Page(Borg, unittest.TestCase):
             self.write('\n--------USEFUL EXCEPTION--------\n')
             for (i, msg) in enumerate(self.exceptions, start=1):
                 self.write(str(i) + "- " + msg)
-        self.base_make_gif()
+        return self.base_make_gif()
 
     def base_make_gif(self):
-        self.make_gif()
+        gif_file = self.make_gif()
         if self.gif_file_name is not None:
             self.write("Screenshots & GIF created at %s" % self.screenshot_dir)
             self.write('************************')
+            return gif_file
 
     def start(self):
         "Overwrite this method in your Page module if you want to visit a specific URL"
